@@ -9,6 +9,8 @@ from naas_drivers.input.pdf import Pdf
 from naas_drivers.input.plotly import Plotly
 from naas_drivers.input.html import Html
 from naas_drivers.input.qonto import Qonto
+from naas_drivers.output.slack import Slack
+from naas_drivers.output.teams import Teams
 from naas_drivers.output.bubble import Bubble
 from naas_drivers.output.healthcheck import Healthcheck
 from naas_drivers.output.ifttt import Ifttt
@@ -32,7 +34,7 @@ from naas_drivers.input.markdown import Markdown
 import requests
 import os
 
-__version__ = "0.39.0"
+__version__ = "0.41.1"
 
 __github_repo = "jupyter-naas/drivers"
 
@@ -51,6 +53,8 @@ pdf = Pdf()
 plotly = Plotly()
 html = Html()
 markdown = Markdown()
+teams = Teams()
+slack = Slack()
 qonto = Qonto()
 
 # Out drivers
